@@ -1,5 +1,5 @@
 #output for ARS
 ARSoutput<-function(sumindexR, sumindexT, R.split, T.split, keindex_ref, keindex_test, Dose, TotalData){
 NCAoutput(sumindexR, sumindexT, R.split, T.split, keindex_ref, keindex_test, Dose, TotalData,
-          NCA=FALSE,ARS=TRUE,TTT=FALSE)
+          NCA=FALSE,ARS=TRUE,TTT=FALSE,aic=FALSE,TTTARS=FALSE,TTTAIC=FALSE)
 }
\ No newline at end of file
