@@ -3,9 +3,7 @@ NCAmenu<-function()
 {
 cat("\n")
   file.menu <- c("Run NCA",
-                 "Run NCA demo (lambda_z est. from the exact 3 data points)",
-                 "Run NCA demo (lambda_z est. with adjusted R sq. (ARS))",
-                 "Run NCA demo (lambda_z est. with Two-Times-Tmax method (TTT))",
+                 "Run NCA demo",
                  "Back to the previous step",
                  "Quit")
  cat("\n")
@@ -17,29 +15,19 @@ cat("\n")
     else {
     if (pick == 2){
         cat("\n")
-       demoNCA() 
+       demomenu() 
        }
     else {
     if (pick == 3){
         cat("\n")
-       demoARS() 
+       go() 
        }
     else {
     if (pick == 4){
         cat("\n")
-       demoTTT() 
+      cat("\nThank you for using bear!  Bye now. \n")}
        }      
-    else {
-    if (pick == 5){
-        cat("\n")
-       go() 
-         }
-   else {
-    if (pick == 6){
-        cat("\nThank you for using bear!  Bye now. \n")}
-           }
-        }
       }
     }
-   }
- }  
\ No newline at end of file
+ }
+   
\ No newline at end of file
